@@ -32,13 +32,13 @@ import os
 import sys
 import time
 import string
-import urllib
 
 import supybot.conf as conf
 import supybot.ircdb as ircdb
 import supybot.utils as utils
 from supybot.commands import *
 import supybot.plugins as plugins
+import supybot.utils.minisix as minisix
 import supybot.ircutils as ircutils
 import supybot.callbacks as callbacks
 import supybot.httpserver as httpserver
@@ -119,7 +119,7 @@ httpserver.set_default_templates(DEFAULT_TEMPLATES)
 class FactoidsCallback(httpserver.SupyHTTPServerCallback):
     name = 'Factoids web interface'
 
-    def doGet(self, handler, path):
+    def doGetOrHead(self, handler, path, write_content):
         parts = path.split('/')[1:]
         if path == '/':
             self.send_response(200)
@@ -127,23 +127,25 @@ class FactoidsCallback(httpserver.SupyHTTPServerCallback):
             self.end_headers()
             self.write(httpserver.get_template('factoids/index.html'))
         elif len(parts) == 2:
-            channel = urllib.unquote(parts[0])
+            channel = utils.web.unquote(parts[0])
             if not ircutils.isChannel(channel):
                 self.send_response(404)
                 self.send_header('Content-type', 'text/html; charset=utf-8')
                 self.end_headers()
-                self.write(httpserver.get_template('generic/error.html')%
-                    {'title': 'Factoids - not a channel',
-                     'error': 'This is not a channel'})
+                if write_content:
+                    self.write(httpserver.get_template('generic/error.html')%
+                        {'title': 'Factoids - not a channel',
+                         'error': 'This is not a channel'})
                 return
             if not self._plugin.registryValue('web.channel', channel):
                 self.send_response(403)
                 self.send_header('Content-type', 'text/html; charset=utf-8')
                 self.end_headers()
-                self.write(httpserver.get_template('generic/error.html')%
-                    {'title': 'Factoids - unavailable',
-                     'error': 'This channel does not exist or its factoids '
-                              'are not available here.'})
+                if write_content:
+                    self.write(httpserver.get_template('generic/error.html')%
+                        {'title': 'Factoids - unavailable',
+                         'error': 'This channel does not exist or its factoids '
+                                  'are not available here.'})
                 return
             db = self._plugin.getDb(channel)
             cursor = db.cursor()
@@ -173,13 +175,14 @@ class FactoidsCallback(httpserver.SupyHTTPServerCallback):
             self.send_response(200)
             self.send_header('Content-type', 'text/html; charset=utf-8')
             self.end_headers()
-            self.write(httpserver.get_template('factoids/channel.html')%
-                    {'channel': channel, 'rows': content})
+            if write_content:
+                self.write(httpserver.get_template('factoids/channel.html')%
+                        {'channel': channel, 'rows': content})
     def doPost(self, handler, path, form):
         if 'chan' in form:
             self.send_response(303)
             self.send_header('Location',
-                    './%s/' % urllib.quote(form['chan'].value))
+                    './%s/' % utils.web.quote(form['chan'].value))
             self.end_headers()
         else:
             self.send_response(400)
@@ -219,11 +222,11 @@ class Factoids(callbacks.Plugin, plugins.ChannelDBHandler):
     def makeDb(self, filename):
         if os.path.exists(filename):
             db = sqlite3.connect(filename)
-            if sys.version_info[0] < 3:
+            if minisix.PY2:
                 db.text_factory = str
             return db
         db = sqlite3.connect(filename)
-        if sys.version_info[0] < 3:
+        if minisix.PY2:
             db.text_factory = str
         cursor = db.cursor()
         cursor.execute("""CREATE TABLE keys (
@@ -248,7 +251,7 @@ class Factoids(callbacks.Plugin, plugins.ChannelDBHandler):
 
     def getCommandHelp(self, command, simpleSyntax=None):
         method = self.getCommandMethod(command)
-        if method.im_func.__name__ == 'learn':
+        if method.__func__.__name__ == 'learn':
             chan = None
             if dynamic.msg is not None:
                 chan = dynamic.msg.args[0]
@@ -358,9 +361,9 @@ class Factoids(callbacks.Plugin, plugins.ChannelDBHandler):
         dl_metrics = [dameraulevenshtein(key, sourcekey) for sourcekey in flkeys]
         dict_metrics = dict(list(zip(flkeys, dl_metrics)))
         if min(dl_metrics) <= 2:
-            return [key for key,item in dict_metrics.iteritems() if item <= 2]
+            return [key for key,item in dict_metrics.items() if item <= 2]
         if min(dl_metrics) <= 3:
-            return [key for key,item in dict_metrics.iteritems() if item <= 3]
+            return [key for key,item in dict_metrics.items() if item <= 3]
         
         return []
                 
