@@ -34,12 +34,12 @@ import cgi
 import json
 import time
 import socket
-import urllib
 
 import supybot.conf as conf
 import supybot.utils as utils
 import supybot.world as world
 from supybot.commands import *
+import supybot.utils.minisix as minisix
 import supybot.ircmsgs as ircmsgs
 import supybot.ircutils as ircutils
 import supybot.callbacks as callbacks
@@ -80,11 +80,21 @@ class Google(callbacks.PluginRegexp):
             msg = ircmsgs.privmsg(msg.args[0], s, msg=msg)
         return msg
 
-    _gsearchUrl = 'http://ajax.googleapis.com/ajax/services/search/web'
-    @internationalizeDocstring
+    _decode_re = re.compile(r'<h3 class="r"><a href="/url\?q=(?P<url>[^"]+)&[^"]+">(?P<title>.*?)</a></h3>.*?<a class="[^"]+" href="/url\?q=(?P<cacheUrl>http://webcache[^"]+)">.*?<span class="st">(?P<content>.*?)</span>', re.DOTALL | re.MULTILINE)
+    @classmethod
+    def decode(cls, text):
+        matches = cls._decode_re.findall(text)
+        results = []
+        for match in matches:
+            r = dict(zip(('url', 'title', 'cacheUrl', 'content'), match))
+            r['url'] = utils.web.htmlToText(r['url'].split('&amp;')[0])
+            results.append(r)
+        return results
+
+
+    _gsearchUrl = 'https://www.google.com/search'
     def search(self, query, channel, options={}):
-        """Perform a search using Google's AJAX API.
-        search("search phrase", options={})
+        """search("search phrase", options={})
 
         Valid options are:
             smallsearch - True/False (Default: False)
@@ -92,14 +102,21 @@ class Google(callbacks.PluginRegexp):
             language - Restrict search to documents in the given language
                        (Default: "lang_en")
         """
+        self.log.warning('The Google plugin search is deprecated since '
+                'Google closed their public API and will be removed in a '
+                'future release. Please consider switching to an other '
+                'plugin for your searches, like '
+                '<https://github.com/Hoaas/Supybot-plugins/tree/master/DuckDuckGo>, '
+                '<https://github.com/joulez/GoogleCSE>, or '
+                '<https://github.com/GLolol/SupyPlugins/tree/master/DDG>.')
         ref = self.registryValue('referer')
         if not ref:
             ref = 'http://%s/%s' % (dynamic.irc.server,
                                     dynamic.irc.nick)
         headers = dict(utils.web.defaultHeaders)
         headers['Referer'] = ref
-        opts = {'q': query, 'v': '1.0'}
-        for (k, v) in options.iteritems():
+        opts = {'q': query, 'gbv': '2'}
+        for (k, v) in options.items():
             if k == 'smallsearch':
                 if v:
                     opts['rsz'] = 'small'
@@ -108,35 +125,30 @@ class Google(callbacks.PluginRegexp):
             elif k == 'filter':
                 opts['safe'] = v
             elif k == 'language':
-                opts['lr'] = v
+                opts['hl'] = v
         defLang = self.registryValue('defaultLanguage', channel)
-        if 'lr' not in opts and defLang:
-            opts['lr'] = defLang
+        if 'hl' not in opts and defLang:
+            opts['hl'] = defLang.strip('lang_')
         if 'safe' not in opts:
             opts['safe'] = self.registryValue('searchFilter', dynamic.channel)
         if 'rsz' not in opts:
             opts['rsz'] = 'large'
 
         text = utils.web.getUrl('%s?%s' % (self._gsearchUrl,
-                                           urllib.urlencode(opts)),
+                                           utils.web.urlencode(opts)),
                                 headers=headers).decode('utf8')
-        data = json.loads(text)
-        if data['responseStatus'] != 200:
-            self.log.info("Google: unhandled error message: ", text)
-            raise callbacks.Error(data['responseDetails'])
-        return data
+        return text
 
     def formatData(self, data, bold=True, max=0, onetoone=False):
-        if isinstance(data, basestring):
-            return data
+        data = self.decode(data)
         results = []
         if max:
             data = data[:max]
         for result in data:
-            title = utils.web.htmlToText(result['titleNoFormatting']\
+            title = utils.web.htmlToText(result['title']\
                                          .encode('utf-8'))
-            url = result['unescapedUrl']
-            if sys.version_info[0] < 3:
+            url = result['url']
+            if minisix.PY2:
                 url = url.encode('utf-8')
             if title:
                 if bold:
@@ -144,7 +156,7 @@ class Google(callbacks.PluginRegexp):
                 results.append(format('%s: %u', title, url))
             else:
                 results.append(url)
-        if sys.version_info[0] < 3:
+        if minisix.PY2:
             repl = lambda x:x if isinstance(x, unicode) else unicode(x, 'utf8')
             results = list(map(repl, results))
         if not results:
@@ -152,7 +164,7 @@ class Google(callbacks.PluginRegexp):
         elif onetoone:
             return results
         else:
-            return [u'; '.join(results)]
+            return [minisix.u('; ').join(results)]
 
     @internationalizeDocstring
     def lucky(self, irc, msg, args, opts, text):
@@ -163,10 +175,11 @@ class Google(callbacks.PluginRegexp):
         """
         opts = dict(opts)
         data = self.search(text, msg.args[0], {'smallsearch': True})
-        if data['responseData']['results']:
-            url = data['responseData']['results'][0]['unescapedUrl']
+        data = self.decode(data)
+        if data:
+            url = data[0]['url']
             if 'snippet' in opts:
-                snippet = data['responseData']['results'][0]['content']
+                snippet = data[0]['content']
                 snippet = " | " + utils.web.htmlToText(snippet, tagReplace='')
             else:
                 snippet = ""
@@ -194,7 +207,7 @@ class Google(callbacks.PluginRegexp):
         # do not want @google to echo ~20 lines of results, even if you
         # have reply.oneToOne enabled.
         onetoone = self.registryValue('oneToOne', msg.args[0])
-        for result in self.formatData(data['responseData']['results'],
+        for result in self.formatData(data,
                                   bold=bold, max=max, onetoone=onetoone):
             irc.reply(result)
     google = wrap(google, [getopts({'language':'something',
@@ -208,8 +221,8 @@ class Google(callbacks.PluginRegexp):
         Returns a link to the cached version of <url> if it is available.
         """
         data = self.search(url, msg.args[0], {'smallsearch': True})
-        if data['responseData']['results']:
-            m = data['responseData']['results'][0]
+        if data:
+            m = data[0]
             if m['cacheUrl']:
                 url = m['cacheUrl'].encode('utf-8')
                 irc.reply(url)
@@ -217,6 +230,7 @@ class Google(callbacks.PluginRegexp):
         irc.error(_('Google seems to have no cache for that site.'))
     cache = wrap(cache, ['url'])
 
+    _fight_re = re.compile(r'id="resultStats"[^>]*>(?P<stats>[^<]*)')
     @internationalizeDocstring
     def fight(self, irc, msg, args):
         """<search string> <search string> [<search string> ...]
@@ -227,9 +241,13 @@ class Google(callbacks.PluginRegexp):
         channel = msg.args[0]
         results = []
         for arg in args:
-            data = self.search(arg, channel, {'smallsearch': True})
-            count = data['responseData']['cursor'].get('estimatedResultCount',
-                                                       0)
+            text = self.search(arg, channel, {'smallsearch': True})
+            i = text.find('id="resultStats"')
+            stats = utils.web.htmlToText(self._fight_re.search(text).group('stats'))
+            if stats == '':
+                results.append((0, args))
+                continue
+            count = ''.join(filter('0123456789'.__contains__, stats))
             results.append((int(count), arg))
         results.sort()
         results.reverse()
@@ -240,6 +258,50 @@ class Google(callbacks.PluginRegexp):
         s = ', '.join([format('%s: %i', bold(s), i) for (i, s) in results])
         irc.reply(s)
 
+
+    def _translate(self, sourceLang, targetLang, text):
+        headers = dict(utils.web.defaultHeaders)
+        headers['User-Agent'] = ('Mozilla/5.0 (X11; U; Linux i686) '
+                                 'Gecko/20071127 Firefox/2.0.0.11')
+
+        sourceLang = utils.web.urlquote(sourceLang)
+        targetLang = utils.web.urlquote(targetLang)
+
+        text = utils.web.urlquote(text)
+
+        result = utils.web.getUrlFd('http://translate.googleapis.com/translate_a/single'
+                                    '?client=gtx&dt=t&sl=%s&tl=%s&q='
+                                    '%s' % (sourceLang, targetLang, text),
+                                    headers).read().decode('utf8')
+
+        while ',,' in result:
+            result = result.replace(',,', ',null,')
+        while '[,' in result:
+            result = result.replace('[,', '[')
+        data = json.loads(result)
+
+        try:
+            language = data[2]
+        except:
+            language = 'unknown'
+
+        if data[0]:
+            return (''.join(x[0] for x in data[0]), language)
+        else:
+            return (_('No translations found.'), language)
+
+    @internationalizeDocstring
+    def translate(self, irc, msg, args, sourceLang, targetLang, text):
+        """<source language> [to] <target language> <text>
+
+        Returns <text> translated from <source language> into <target
+        language>.
+        """
+        channel = msg.args[0]
+        (text, language) = self._translate(sourceLang, targetLang, text)
+        irc.reply(text, language)
+    translate = wrap(translate, ['something', 'to', 'something', 'text'])
+
     def googleSnarfer(self, irc, msg, match):
         r"^google\s+(.*)$"
         if not self.registryValue('searchSnarfer', msg.args[0]):
@@ -252,7 +314,7 @@ class Google(callbacks.PluginRegexp):
     googleSnarfer = urlSnarfer(googleSnarfer)
 
     def _googleUrl(self, s, channel):
-        s = urllib.quote_plus(s)
+        s = utils.web.urlquote_plus(s)
         url = r'http://%s/search?q=%s' % \
                 (self.registryValue('baseUrl', channel), s)
         return url
