@@ -133,9 +133,9 @@ class MessageParserTestCase(ChannelPluginTestCase):
         self.assertRegexp('messageparser list', 
                 'There are no regexp triggers in the database\.')
         self.assertNotError('messageparser add "stuff" "echo i saw some stuff"')
-        self.assertRegexp('messageparser list', '"stuff" \(1\)')
+        self.assertRegexp('messageparser list', '\x02#1\x02: stuff')
         self.assertNotError('messageparser add "aoeu" "echo vowels are nice!"')
-        self.assertRegexp('messageparser list', '"stuff" \(1\), "aoeu" \(2\)')
+        self.assertRegexp('messageparser list', '\x02#1\x02: stuff, \x02#2\x02: aoeu')
         
     def testRemove(self):
         self.assertError('messageparser remove "stuff"')
