@@ -44,6 +44,7 @@ import supybot.utils as utils
 from supybot.commands import *
 import supybot.ircdb as ircdb
 import supybot.irclib as irclib
+import supybot.utils.minisix as minisix
 import supybot.ircmsgs as ircmsgs
 import supybot.ircutils as ircutils
 import supybot.callbacks as callbacks
@@ -53,7 +54,7 @@ from supybot import commands
 from supybot.i18n import PluginInternationalization, internationalizeDocstring
 _ = PluginInternationalization('Misc')
 
-if sys.version_info[0] < 3:
+if minisix.PY2:
     from itertools import ifilter as filter
 
 def get_suffix(file):
@@ -170,9 +171,9 @@ class Misc(callbacks.Plugin):
             if tokens:
                 # echo [] will get us an empty token set, but there's no need
                 # to log this in that case anyway, it being a nested command.
-                self.log.info('Not replying to %s in %s, not a command.' %
-                    (tokens[0], channel
-                    if channel != irc.nick else _('private')))
+                self.log.info('Not replying to %s in %s, not a command.',
+                    tokens[0], channel
+                    if channel != irc.nick else _('private'))
             if irc.nested:
                 bracketConfig = conf.supybot.commands.nested.brackets
                 brackets = conf.get(bracketConfig, channel)
@@ -270,7 +271,7 @@ class Misc(callbacks.Plugin):
                 for command in cb.listCommands():
                     if s in command:
                         commands.setdefault(command, []).append(cb.name())
-        for (key, names) in commands.iteritems():
+        for (key, names) in commands.items():
             for name in names:
                 L.append('%s %s' % (name, key))
         if L:
@@ -336,7 +337,7 @@ class Misc(callbacks.Plugin):
                 version = data['commit']['committer']['date']
                 # Strip the last 'Z':
                 version = version.rsplit('T', 1)[0].replace('-', '.')
-                if sys.version_info[0] < 3 and isinstance(version, unicode):
+                if minisix.PY2 and isinstance(version, unicode):
                     version = version.encode('utf8')
                 versions[branch] = version
             newest = _('The newest versions available online are %s.') % \
@@ -346,7 +347,7 @@ class Misc(callbacks.Plugin):
             self.log.info('Couldn\'t get website version: %s', e)
             newest = _('I couldn\'t fetch the newest version '
                      'from the Limnoria repository.')
-        s = _('The current (running) version of this Supybot is %s, '
+        s = _('The current (running) version of this Limnoria is %s, '
               'running on Python %s.  %s') % \
             (conf.version, sys.version.replace('\n', ' '), newest)
         irc.reply(s)
@@ -385,7 +386,7 @@ class Misc(callbacks.Plugin):
         try:
             L = irc._mores[userHostmask]
             number = self.registryValue('mores', msg.args[0])
-            chunks = [L.pop() for x in xrange(0, number)]
+            chunks = [L.pop() for x in range(0, number)]
             if L:
                 if len(L) < 2:
                     more = _('1 more message')
@@ -454,7 +455,7 @@ class Misc(callbacks.Plugin):
                     def f1(s, arg):
                         """Since we can't enqueue match objects into the multiprocessing queue,
                         we'll just wrap the function to return bools."""
-                        if arg.search(s) is not None:
+                        if process(arg.search, s, timeout=0.1) is not None:
                             return True
                         else:
                             return False
@@ -473,7 +474,7 @@ class Misc(callbacks.Plugin):
             # Drop the first message only if our current channel is the same as
             # the channel we've been instructed to look at.
             next(iterable)
-        predicates = list(utils.iter.flatten(predicates.itervalues()))
+        predicates = list(utils.iter.flatten(predicates.values()))
         # Make sure the user can't get messages from channels they aren't in
         def userInChannel(m):
             return m.args[0] in irc.state.channels \
