@@ -32,7 +32,6 @@ import re
 import sys
 import time
 import json
-import urllib
 
 import supybot.log as log
 import supybot.conf as conf
@@ -77,7 +76,7 @@ class ShrinkError(Exception):
 
 def retry(f):
     def newf(*args, **kwargs):
-        for x in xrange(0, 3):
+        for x in range(0, 3):
             try:
                 return f(*args, **kwargs)
             except Exception:
@@ -125,8 +124,10 @@ class ShrinkUrl(callbacks.PluginRegexp):
         irc.queueMsg(newMsg)
 
     def outFilter(self, irc, msg):
+        if msg.command != 'PRIVMSG':
+            return msg
         channel = msg.args[0]
-        if msg.command == 'PRIVMSG' and irc.isChannel(channel):
+        if irc.isChannel(channel):
             if not msg.shrunken:
                 if self.registryValue('outFilter', channel):
                     if utils.web.httpUrlRe.search(msg.args[1]):
