@@ -33,7 +33,9 @@ Simple utility modules.
 """
 
 import re
+import ssl
 import socket
+import hashlib
 
 from .web import _ipAddr, _domain
 
@@ -62,24 +64,30 @@ def getSocket(host, port=None, socks_proxy=None, vhost=None, vhostv6=None):
         s.setproxy(socks.PROXY_TYPE_SOCKS5, hostname, int(port),
                 rdns=True)
         return s
-    import supybot.conf as conf
     if isIPV4(host):
         s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        if not vhost:
-            vhost = conf.supybot.protocols.irc.vhost()
         if vhost:
             s.bind((vhost, 0))
         return s
     elif isIPV6(host):
         s = socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
-        if not vhostv6:
-            vhostv6 = conf.supybot.protocols.irc.vhostv6()
         if vhostv6:
             s.bind((vhostv6, 0))
         return s
     else:
         raise socket.error('Something wonky happened.')
 
+def isSocketAddress(s):
+    if ':' in s:
+        host, port = s.rsplit(':', 1)
+        try:
+            int(port)
+            sock = getSocket(host, port)
+            return True
+        except (ValueError, socket.error):
+            pass
+    return False
+
 def isIP(s):
     """Returns whether or not a given string is an IP address.
 
@@ -133,4 +141,53 @@ def isIPV6(s):
             return bruteIsIPV6(s)
         return False
 
+
+normalize_fingerprint = lambda fp: fp.replace(':', '').lower()
+
+FINGERPRINT_ALGORITHMS = ('md5', 'sha1', 'sha224', 'sha256', 'sha384',
+        'sha512')
+def check_certificate_fingerprint(conn, trusted_fingerprints):
+    trusted_fingerprints = set(normalize_fingerprint(fp)
+            for fp in trusted_fingerprints)
+    cert = conn.getpeercert(binary_form=True)
+    for algorithm in FINGERPRINT_ALGORITHMS:
+        h = hashlib.new(algorithm)
+        h.update(cert)
+        if h.hexdigest() in trusted_fingerprints:
+            return
+    raise ssl.CertificateError('No matching fingerprint.')
+
+if hasattr(ssl, 'create_default_context'):
+    def ssl_wrap_socket(conn, hostname, logger, certfile=None,
+            trusted_fingerprints=None, verify=True, ca_file=None,
+            **kwargs):
+        context = ssl.create_default_context(**kwargs)
+        if trusted_fingerprints or not verify:
+            # Do not use Certification Authorities
+            context.check_hostname = False
+            context.verify_mode = ssl.CERT_NONE
+        if ca_file:
+            context.load_verify_locations(cafile=ca_file)
+        if certfile:
+            context.load_cert_chain(certfile)
+        conn = context.wrap_socket(conn, server_hostname=hostname)
+        if verify and trusted_fingerprints:
+            check_certificate_fingerprint(conn, trusted_fingerprints)
+        return conn
+else:
+    def ssl_wrap_socket(conn, hostname, logger, verify=True,
+            certfile=None,
+            ca_file=None, trusted_fingerprints=None):
+        # TLSv1.0 is the only TLS version Python < 2.7.9 supports
+        # (besides SSLv2 and v3, which are known to be insecure)
+        conn = ssl.wrap_socket(conn, certfile=certfile, ca_certs=ca_file,
+                ssl_version=ssl.PROTOCOL_TLSv1)
+        if trusted_fingerprints:
+            check_certificate_fingerprint(conn, trusted_fingerprints)
+        elif verify:
+            logger.critical('This Python version does not support SSL/TLS '
+                    'certification authority verification, which makes your '
+                    'connection vulnerable to man-in-the-middle attacks. See: '
+                    '<http://doc.supybot.aperio.fr/en/latest/use/security.html#ssl-python-versions>')
+        return conn
 # vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
